globalVariables(c("exprs",
    "pData",
    "row_id",
    "value",
    "variable",
    "xend",
    "x",
    "y",
    "yend",
    "y.x",
    "y.y",
    "logFC",
    "PValue",
    "FDR"))
